==> chyk-0.1.5-py3-none-any.whl: chyk/__init__.py <==
import handcalcs.render
import forallpeople as u
u.environment('default')
from IPython.display import Latex
from math import sqrt, pi, cos, sin, tan, log10, log2, log, e, atan2, acos, asin
import numpy as np
sqrt = np.emath.sqrt
from matplotlib import pyplot as plt
from scipy.integrate import quad
from scipy.optimize import fsolve
from scipy.constants import c
from latex2sympy2 import latex2sympy, latex2latex
import sympy as sym
from sympy import roots
from sympy.abc import x, a, b, c
from sympy import integrate
from sympy import lambdify
from sympy import Symbol
from sympy.solvers import solve
from tabulate import tabulate
import pandas as pd
from fgmkr import fgmk, fgmk2, fgmk_help

# Separates imaginary and real components
def ri(imag):
    return [sp.re(imag), sp.im(imag)]

# Finds angle in degrees of an imaginary number
def ang(imag):
    return atan2(sp.im(imag),sp.re(imag))*180/pi

# Custom notation to pretty-fy outputs for phasor notation
deg = Symbol('^\circ')
deg_C = Symbol('^\circ\,C')
deg_K = Symbol('^\circ\,K')
aag = Symbol('\, Magnitude\, \, @ \,')
def cphas(mag_in, angle_in):
    return mag_in*aag + angle_in*deg

# Embedded Separators
Part_A = Symbol('Part\, A\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :')
Part_B = Symbol('Part\, B\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :')
Part_C = Symbol('Part\, C\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :')
Part_D = Symbol('Part\, D\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :')

# Debugging Marker
mk = Symbol('marker \quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :')

==> chyk-0.1.6-py3-none-any.whl: chyk/__init__.py <==
import handcalcs.render
import forallpeople as u
u.environment('default')
from IPython.display import Latex
from math import sqrt, pi, cos, sin, tan, log10, log2, log, e, atan2, acos, asin
import numpy as np
sqrt = np.emath.sqrt
from matplotlib import pyplot as plt
from scipy.integrate import quad
from scipy.optimize import fsolve
from scipy.constants import c
from latex2sympy2 import latex2sympy, latex2latex
import sympy as sym
from sympy import roots
from sympy.abc import x, a, b
from sympy import integrate
from sympy import lambdify
from sympy import Symbol
from sympy.solvers import solve
from tabulate import tabulate
import pandas as pd
from fgmkr import fgmk, fgmk2, fgmk_help

# Separates imaginary and real components
def ri(imag):
    return [sp.re(imag), sp.im(imag)]

# Finds angle in degrees of an imaginary number
def ang(imag):
    return atan2(sp.im(imag),sp.re(imag))*180/pi

# Custom notation to pretty-fy outputs for phasor notation
deg = Symbol('^\circ')
deg_C = Symbol('^\circ\,C')
deg_K = Symbol('^\circ\,K')
aag = Symbol('\, Magnitude\, \, @ \,')
def cphas(mag_in, angle_in):
    return mag_in*aag + angle_in*deg

# Embedded Separators
Part_A = Symbol('Part\, A\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :')
Part_B = Symbol('Part\, B\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :')
Part_C = Symbol('Part\, C\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :')
Part_D = Symbol('Part\, D\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :')

# Debugging Marker
mk = Symbol('marker \quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :\quad :')
